import { Host, h } from '@stencil/core';
import Cookies from 'js-cookie';
import { createFocusTrap } from 'focus-trap';
import classNames from 'classnames';
import { cookieTranslations } from '../../services/default-cookie-translations.js';
import { Environment } from '../../services/environment.js';
export class CookieConsent {
  constructor() {
    this.showCategories = () => {
      return this.checkedCategories.map((category, key) => h("aui-cookie-category", { data: category, translations: this.translationData, index: key }));
    };
    this.checkCookieConfig = () => {
      return this.checkedCategories.length === 0
        ? h("div", { role: "alertdialog", class: "m-alert m-alert--danger m-alert--inline u-margin-bottom" }, h("p", null, "No cookie consent configuration found."))
        : null;
    };
    this.showCookieConsentDashboard = () => {
      return (h("div", null, h("div", { class: "m-modal__body" }, this.checkCookieConfig(), h("h1", { class: "h3 u-margin-bottom" }, this.configData.title), h("p", { class: "u-margin-bottom", innerHTML: this.configData.intro })), h("div", { class: "m-modal__footer" }, h("button", { class: "a-button", onClick: (e) => this.handleAcceptAll(e) }, this.translationData.buttonAccept), h("button", { class: "a-button", onClick: (e) => this.handleAcceptOnlyNecessary(e) }, this.translationData.buttonReject), h("button", { class: "a-button", onClick: () => this.handleShowPreferences() }, this.translationData.buttonSetup))));
    };
    this.showCookieConsentPreferences = () => {
      return (h("div", null, h("div", { class: "m-modal__body" }, this.checkCookieConfig(), h("div", { class: "m-modal__top-buttons" }, h("p", null, h("a", { role: "button", href: "#", class: "has-icon-left", onClick: () => this.handleShowPreferences() }, h("aui-icon", { name: "ai-arrow-left-1" }), this.translationData.buttonBack)), this.checkCookiePolicy()), h("h1", { class: "h3 u-margin-top u-margin-bottom" }, this.translationData.textCookieTypes), this.showCategories()), h("div", { class: "m-modal__footer u-margin-top" }, h("button", { class: "a-button", onClick: () => this.savePreferences() }, this.translationData.buttonSaveSettings))));
    };
    this.branding = 'aui';
    this.config = undefined;
    this.openPreferences = undefined;
    this.translations = undefined;
    this.environment = undefined;
    this.domain = undefined;
    this.excludedpaths = undefined;
    this.preferencesSaved = undefined;
    this.configData = {};
    this.translationData = undefined;
    this.hidden = false;
    this.showPreferences = false;
    this.checkedCategories = [];
    this.currentEnvironment = undefined;
    this.openedManually = false;
  }
  componentWillLoad() {
    this.handleTranslations();
    this.loadConfigAndTranslations();
    this.checkEnvironment();
    this.checkCookie();
    this.checkExcludedPaths();
  }
  componentDidLoad() {
    if (!this.configData.nonBlocking && !this.hidden) {
      const focusTrap = createFocusTrap(this.componentRef);
      setTimeout(() => focusTrap.activate());
    }
  }
  parseConfigProp(newValue) {
    if (newValue)
      this.configData = JSON.parse(newValue);
    this.checkedCategories = this.configData.cookieConfig;
  }
  parseTranslationsProp(newValue) {
    if (newValue)
      this.handleTranslations(JSON.parse(newValue));
  }
  watchHandler(newValue) {
    this.checkCookie();
    this.hidden = !newValue;
    this.showPreferences = newValue;
    this.openedManually = true;
  }
  handleCheckCategory(event) {
    const key = event.detail;
    const newCategories = this.checkedCategories.map((cat, i) => {
      if (key === i) {
        return Object.assign(Object.assign({}, cat), { enabled: !cat.enabled });
      }
      return cat;
    });
    this.checkedCategories = [...newCategories];
  }
  handleOpenCloseCategory(event) {
    const key = event.detail;
    const newCategories = this.checkedCategories.map((cat, i) => {
      if (key === i) {
        return Object.assign(Object.assign({}, cat), { open: !cat.open });
      }
      return cat;
    });
    this.checkedCategories = [...newCategories];
  }
  checkExcludedPaths() {
    if (this.excludedpaths && this.excludedpaths.length > 0) {
      const excludedPaths = this.excludedpaths.split(",");
      if (excludedPaths.indexOf(window.location.pathname) > -1) {
        this.hideModal();
      }
    }
  }
  loadConfigAndTranslations() {
    if (this.config) {
      this.parseConfigProp(this.config);
    }
    if (this.translations) {
      this.parseTranslationsProp(this.translations);
    }
  }
  handleTranslations(translations = {}) {
    this.translationData = Object.assign(Object.assign({}, cookieTranslations), translations);
  }
  checkEnvironment() {
    if (this.environment) {
      this.currentEnvironment = this.environment;
    }
    else {
      this.currentEnvironment = Environment.getEnvironment();
    }
  }
  setCookie(type) {
    let cookiePreferences = [];
    if (Cookies.get('cookiepreferences_' + this.currentEnvironment)) {
      cookiePreferences = JSON.parse(Cookies.get('cookiepreferences_' + this.currentEnvironment));
    }
    this.checkedCategories.forEach(function (category) {
      // Make sure cookies from the same subdomain are left untouched
      const index = cookiePreferences.map(e => e.category).indexOf(category.name);
      if (index > -1) {
        cookiePreferences[index].accepted = (type === 'all' ? true : category.enabled);
      }
      else {
        cookiePreferences = [...cookiePreferences, Object.assign({ category: category.name, accepted: (type === 'all' ? true : category.enabled) }, (category.id) && { id: category.id })];
      }
    });
    Cookies.set('cookiepreferences_' + this.currentEnvironment, cookiePreferences, { domain: this.domain || window.location.hostname, expires: 365 });
    if (this.preferencesSaved) {
      this.preferencesSaved(cookiePreferences);
    }
  }
  checkCookie() {
    let hideWindow = false;
    if (Cookies.get('cookiepreferences_' + this.currentEnvironment)) {
      let cookiePreferences = JSON.parse(Cookies.get('cookiepreferences_' + this.currentEnvironment));
      let checkedCategories = [...this.checkedCategories];
      cookiePreferences.forEach(function (cookiePref) {
        let index = checkedCategories.findIndex((obj => obj.name === cookiePref.category));
        if (checkedCategories[index]) {
          hideWindow = true;
          checkedCategories[index].enabled = cookiePref.accepted;
        }
      });
      this.checkedCategories = checkedCategories;
    }
    this.hidden = hideWindow;
  }
  checkCookiePolicy() {
    var cookiePolicy = !!this.configData.cookiePolicy
      ? (h("p", null, h("a", { href: this.configData.cookiePolicy }, this.translationData.textCookiePolicy)))
      : null;
    return cookiePolicy;
  }
  openCookiePreferences() {
    this.hidden = false;
    this.showPreferences = true;
  }
  handleAcceptAll(e) {
    e.preventDefault();
    this.setCookie('all');
    this.hidden = true;
    this.openPreferences = false;
  }
  handleAcceptOnlyNecessary(e) {
    e.preventDefault();
    this.checkedCategories.forEach(function (category) {
      category.enabled = !category.showSwitch;
    });
    this.setCookie();
    this.hidden = true;
    this.openPreferences = false;
  }
  handleShowPreferences() {
    this.showPreferences = !this.showPreferences;
    setTimeout(() => this.modalRef.focus());
  }
  handleHidePreferences() {
    this.showPreferences = false;
    if (this.openedManually) {
      this.hidden = true;
      this.openedManually = false;
      this.openPreferences = false;
    }
  }
  savePreferences() {
    this.setCookie();
    this.hidden = true;
    this.openPreferences = false;
  }
  hideModal() {
    this.hidden = true;
  }
  render() {
    const overlayClass = classNames('m-overlay', {
      'm-cookie-consent': true,
      'is-active': !this.hidden,
    });
    if (this.configData.nonBlocking && !this.showPreferences && !this.hidden) {
      return (h(Host, { class: this.branding }, h("div", { class: "m-cookie-consent m-cookie-consent--non-blocking" }, h("div", { class: "u-container m-cookie-consent__content u-margin-top u-margin-bottom" }, h("div", { class: "m-cookie-consent__text" }, h("h1", { class: "h3 u-margin-bottom" }, this.configData.title), h("p", { innerHTML: this.configData.intro })), h("div", { class: "m-cookie-consent__buttons" }, h("button", { class: "a-button", onClick: (e) => this.handleAcceptAll(e) }, this.translationData.buttonAccept), h("button", { class: "a-button", onClick: (e) => this.handleAcceptOnlyNecessary(e) }, this.translationData.buttonReject), h("button", { class: "a-button", onClick: () => this.handleShowPreferences() }, this.translationData.buttonSetup))))));
    }
    return (h(Host, { class: this.branding, tabindex: "-1", role: "dialog", "aria-label": "Cookies", "aria-modal": "true", ref: (el) => this.componentRef = el }, h("div", { class: overlayClass }, h("div", { class: 'm-overlay__inner' }, h("div", { class: "m-modal m-modal--l", tabindex: 0, ref: (el) => this.modalRef = el }, h("div", { class: "m-modal__content" }, !this.showPreferences ? this.showCookieConsentDashboard() : this.showCookieConsentPreferences()))))));
  }
  static get is() { return "aui-cookie-consent"; }
  static get originalStyleUrls() {
    return {
      "$": ["cookie-consent.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["cookie-consent.css"]
    };
  }
  static get properties() {
    return {
      "branding": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Extra CSS class(es) to add"
        },
        "attribute": "branding",
        "reflect": false,
        "defaultValue": "'aui'"
      },
      "config": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Configuration of your cookie consent window"
        },
        "attribute": "config",
        "reflect": false
      },
      "openPreferences": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "If set to true, the modal will show the cookie preferences and not the default screen with the title and description"
        },
        "attribute": "open-preferences",
        "reflect": false
      },
      "translations": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Set the translation strings for the cookie consent"
        },
        "attribute": "translations",
        "reflect": false
      },
      "environment": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Set the current enovironment, this will impact the name of the cookie where the preferences will be saved. eg. 'acceptance'"
        },
        "attribute": "environment",
        "reflect": false
      },
      "domain": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Set the domain where you want your cookiepreferences to be saved. eg. 'antwerpen.be'"
        },
        "attribute": "domain",
        "reflect": false
      },
      "excludedpaths": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Single path or comma seperated list of paths on which the cookie consent will not open"
        },
        "attribute": "excludedpaths",
        "reflect": false
      },
      "preferencesSaved": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Function",
          "resolved": "Function",
          "references": {
            "Function": {
              "location": "global"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Runs when new cookie preferences are saved"
        }
      }
    };
  }
  static get states() {
    return {
      "configData": {},
      "translationData": {},
      "hidden": {},
      "showPreferences": {},
      "checkedCategories": {},
      "currentEnvironment": {},
      "openedManually": {}
    };
  }
  static get watchers() {
    return [{
        "propName": "config",
        "methodName": "parseConfigProp"
      }, {
        "propName": "translations",
        "methodName": "parseTranslationsProp"
      }, {
        "propName": "openPreferences",
        "methodName": "watchHandler"
      }];
  }
  static get listeners() {
    return [{
        "name": "checkCategory",
        "method": "handleCheckCategory",
        "target": undefined,
        "capture": false,
        "passive": false
      }, {
        "name": "openCloseCategory",
        "method": "handleOpenCloseCategory",
        "target": undefined,
        "capture": false,
        "passive": false
      }];
  }
}
//# sourceMappingURL=cookie-consent.js.map
