import { h } from '@stencil/core';
import classNames from 'classnames';
export class CookieTable {
  constructor() {
    this.loadCookieTableBody = (data) => {
      return data.cookies.map((cookie) => h("tr", null, h("td", null, cookie.cookie), h("td", null, cookie.type), h("td", null, cookie.duration), h("td", null, cookie.description, cookie.subCookies &&
        h("table", { class: "a-table a-table--open u-margin-top-xxs" }, cookie.subCookies.map((subCookie) => h("tr", { class: "is-condensed" }, h("td", { class: "is-condensed" }, subCookie.name), h("td", { class: "is-condensed" }, subCookie.duration)))))));
    };
    this.data = undefined;
    this.translations = undefined;
    this.leftShadow = false;
    this.rightShadow = false;
  }
  handleResize() {
    this.handleScroll();
  }
  componentDidLoad() {
    this.handleScroll();
  }
  handleScroll() {
    const el = this.tableRef.scrollLeft;
    const width = this.tableRef.scrollWidth - this.tableRef.clientWidth;
    this.leftShadow = (el <= 0) ? false : true;
    this.rightShadow = (el < width) ? true : false;
  }
  render() {
    const tableClasses = classNames('a-table-responsive-wrapper', {
      'has-shadow-left': this.leftShadow,
      'has-shadow-right': this.rightShadow,
    });
    return (h("div", { class: tableClasses }, h("div", { class: "a-table-scrollable-wrapper", onScroll: () => this.handleScroll(), ref: (el) => this.tableRef = el }, h("table", { class: "a-table" }, h("thead", null, h("tr", null, h("th", null, this.translations.tableHeaderCookie), h("th", null, this.translations.tableHeaderType), h("th", null, this.translations.tableHeaderDuration), h("th", null, this.translations.tableHeaderDescription))), h("tbody", null, this.loadCookieTableBody(this.data))))));
  }
  static get is() { return "aui-cookie-table"; }
  static get properties() {
    return {
      "data": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "any[]",
          "resolved": "any[]",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        }
      },
      "translations": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "TranslationsInterface",
          "resolved": "TranslationsInterface",
          "references": {
            "TranslationsInterface": {
              "location": "import",
              "path": "../cookie-consent.interface"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        }
      }
    };
  }
  static get states() {
    return {
      "leftShadow": {},
      "rightShadow": {}
    };
  }
  static get listeners() {
    return [{
        "name": "resize",
        "method": "handleResize",
        "target": "window",
        "capture": false,
        "passive": true
      }];
  }
}
//# sourceMappingURL=cookie-table.js.map
