import { Host, h } from '@stencil/core';
import { contentBlockerTranslations } from '../../services/default-cookie-translations.js';
export class ContentBlocker {
  constructor() {
    this.message = undefined;
    this.description = undefined;
    this.icon = undefined;
    this.branding = 'aui';
    this.translations = '';
    this.translationData = undefined;
  }
  componentWillLoad() {
    this.handleTranslations();
    this.parseTranslationsProp(this.translations);
  }
  parseTranslationsProp(newValue) {
    if (newValue)
      this.handleTranslations(JSON.parse(newValue));
  }
  handleTranslations(translations = {}) {
    this.translationData = Object.assign(Object.assign({}, contentBlockerTranslations), translations);
  }
  openCookiePreferences() {
    const cookieConsentElement = document.querySelector('aui-cookie-consent');
    cookieConsentElement.openPreferences = true;
  }
  render() {
    return (h(Host, { class: this.branding }, h("div", { class: "m-card m-card--gray" }, h("div", { class: "u-text-center u-margin" }, this.icon &&
      h("aui-icon", { name: this.icon, branding: "h2 u-margin-bottom-xs" }), h("h3", { class: "h6" }, this.message), h("p", { class: "u-margin-bottom-xs" }, this.description), h("button", { class: "a-button", onClick: () => this.openCookiePreferences() }, this.translationData.buttonOpenCookieSettings)))));
  }
  static get is() { return "aui-cookie-content-blocker"; }
  static get originalStyleUrls() {
    return {
      "$": ["cookie-content-blocker.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["cookie-content-blocker.css"]
    };
  }
  static get properties() {
    return {
      "message": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The content blocker title"
        },
        "attribute": "message",
        "reflect": false
      },
      "description": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "A paragraph text to explain the content blocker title"
        },
        "attribute": "description",
        "reflect": false
      },
      "icon": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The icon name (eg: ai-close)"
        },
        "attribute": "icon",
        "reflect": false
      },
      "branding": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Extra CSS class(es) to add"
        },
        "attribute": "branding",
        "reflect": false,
        "defaultValue": "'aui'"
      },
      "translations": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Set the translation strings for the content blocker"
        },
        "attribute": "translations",
        "reflect": false,
        "defaultValue": "''"
      }
    };
  }
  static get states() {
    return {
      "translationData": {}
    };
  }
  static get watchers() {
    return [{
        "propName": "translations",
        "methodName": "parseTranslationsProp"
      }];
  }
}
//# sourceMappingURL=cookie-content-blocker.js.map
