import { Host, h } from '@stencil/core';
import classNames from 'classnames';
export class Icon {
  constructor() {
    /**
     * Inject SVG icons from core branding into page
     */
    this.fetchAntwerpIcons = async () => {
      if (!fetch)
        return;
      try {
        const xlinkHref = 'https://cdn.antwerpen.be/core_branding_scss/6.6.4/assets/images/ai.svg';
        const response = await fetch(xlinkHref);
        const svgText = await response.text();
        const svgWrapper = document.createElement('svg');
        svgWrapper.id = 'ai-svg';
        svgWrapper.innerHTML = svgText;
        if (!document.getElementById('ai-svg')) {
          document.body.appendChild(svgWrapper);
        }
      }
      catch (err) {
        throw new Error(err);
      }
    };
    this.name = undefined;
    this.ariaLabel = undefined;
    this.branding = undefined;
  }
  render() {
    if (typeof document !== 'undefined' && !document.getElementById('ai-svg')) {
      this.fetchAntwerpIcons();
    }
    const iconClass = classNames(this.branding, this.name, 'ai');
    return (h(Host, null, h("span", { class: iconClass }, h("svg", { "aria-hidden": "true" }, h("use", { xlinkHref: `#${this.name}` })), this.ariaLabel && h("span", { class: "u-screen-reader-only" }, this.ariaLabel))));
  }
  static get is() { return "aui-icon"; }
  static get properties() {
    return {
      "name": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The icon name (eg: ai-close)"
        },
        "attribute": "name",
        "reflect": false
      },
      "ariaLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": "The ARIA label"
        },
        "attribute": "aria-label",
        "reflect": false
      },
      "branding": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": "Additional CSS class(es)"
        },
        "attribute": "branding",
        "reflect": false
      }
    };
  }
}
//# sourceMappingURL=icon.js.map
